cmd

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 5, 2022 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Copyright © 2022 focks cskkman@gmail.com

Copyright © 2022 focks cskkman@gmail.com

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckError

func CheckError(msg interface{})

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type Api

type Api struct {
	Name             string
	Method           string
	Path             string
	Uri              string
	ProjectDirectory string
	PackageName      string
}

func (*Api) Create

func (a *Api) Create() error

func (*Api) String added in v0.0.3

func (a *Api) String() string

type ApiFile added in v0.0.3

type ApiFile struct {
	// contains filtered or unexported fields
}

type ApibuildrProject added in v0.0.3

type ApibuildrProject struct {
	GoPackage        string
	WorkingDirectory string
	ProjectName      string
}

func (*ApibuildrProject) Create added in v0.0.3

func (project *ApibuildrProject) Create() error

type App added in v0.0.3

type App struct {
	Name         string
	AppDirectory string
	Wd           string
	PackageName  string
}

func (*App) Create added in v0.0.3

func (app *App) Create() error

type CurDir

type CurDir struct {
	Dir string
}

type InitFileVars

type InitFileVars struct {
	Package string
	Path    string
}

type Microservice added in v0.0.3

type Microservice struct {
	Name         string
	AbsolutePath string
	Wd           string
	PackageName  string
}

func (*Microservice) Create added in v0.0.3

func (svc *Microservice) Create() error

type Mod

type Mod struct {
	Path, Dir, GoMod string
}

Directories

Path Synopsis

Jump to